BubbleChartRenderer class

Canvas-based bubble chart — scatter with variable point size.

Inheritance

Constructors

BubbleChartRenderer({double minRadius = 4, double maxRadius = 24, String sizeKey = kBubbleSizeKey})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
maxRadius double
final
minRadius double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sizeKey String
final

Methods

draw(Canvas canvas, Size size, ChartContext context) → void
override
hitRegions(ChartContext context) List<HitRegion>
Optional hit regions for interaction.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited