ChartAnimationController class

Wraps Flutter animation primitives for chart transitions.

Constructors

ChartAnimationController({required TickerProvider vsync, Duration duration = const Duration(milliseconds: 380), Curve curve = Curves.easeInOut})

Properties

animation Animation<double>
no setter
hashCode int
The hash code for this object.
no setterinherited
isAnimating bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value double
no setter

Methods

dispose() → void
forward({double? from}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
reverse() Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited