ChartInterpolation class
Linear interpolation utilities for animated chart updates.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
lerp(
double a, double b, double t) → double -
lerpPoint(
ChartPoint a, ChartPoint b, double t) → ChartPoint -
lerpSeries(
List< ChartPoint> from, List<ChartPoint> to, double t) → List<ChartPoint>