AxisEngine class
Draws axes and grid lines on canvas.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
drawAxes(
Canvas canvas, ChartContext context, {int tickCount = 5}) → void -
drawAxisTitles(
Canvas canvas, ChartContext context) → void - Draws optional X/Y axis title labels (cartesian charts).
-
drawGrid(
Canvas canvas, ChartContext context, {int tickCount = 5}) → void