ChartContext class

Shared runtime context passed to all renderers and layers.

Constructors

ChartContext({required ChartConfig config, required ChartTheme theme, required ChartBounds bounds, required ChartViewport viewport, required CoordinateTransformer transformer, required PaintCache paintCache, double animationValue = 1.0, ChartHitResult? hoveredHit, ChartHitResult? selectedHit, Offset? crosshairPosition, ZoomPanController? zoomPan})

Properties

animationValue double
final
bounds ChartBounds
final
config ChartConfig
final
crosshairPosition Offset?
final
hashCode int
The hash code for this object.
no setterinherited
hoveredHit ChartHitResult?
final
paintCache PaintCache
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedHit ChartHitResult?
final
theme ChartTheme
final
transformer CoordinateTransformer
final
viewport ChartViewport
final
zoomPan ZoomPanController?
final

Methods

copyWith({ChartConfig? config, ChartTheme? theme, ChartBounds? bounds, ChartViewport? viewport, CoordinateTransformer? transformer, PaintCache? paintCache, double? animationValue, ChartHitResult? hoveredHit, ChartHitResult? selectedHit, Offset? crosshairPosition, ZoomPanController? zoomPan, bool clearHover = false, bool clearSelection = false, bool clearCrosshair = false}) ChartContext
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited