HitRegion class

A hit-testable region in canvas space.

Constructors

HitRegion({required Rect bounds, required String seriesId, required int pointIndex, double? dataX, double? dataY, double? dataPercent, String? label})
const

Properties

bounds Rect
final
dataPercent double?
final
dataX double?
final
dataY double?
final
hashCode int
The hash code for this object.
no setterinherited
label String?
final
pointIndex int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seriesId String
final

Methods

contains(Offset position) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited