PluginRegistry class

Registry for external chart plugins.

Constructors

PluginRegistry()

Properties

hashCode int
The hash code for this object.
no setterinherited
layers List<ChartLayer>
no setter
renderers List<ChartRenderer>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerGesture(GestureEngine gesture) → void
registerLayer(ChartLayer layer) → void
registerRenderer(ChartRenderer renderer) → void
registerTooltip(TooltipController tooltip) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited