RenderPipeline class

Orchestrates layered rendering with optional dirty-region support.

Constructors

RenderPipeline({required LayerStack layerStack})

Properties

hasDirtyRegion bool
no setter
hashCode int
The hash code for this object.
no setterinherited
layerStack LayerStack
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearDirty() → void
markDirty(Rect region) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size, ChartContext context) → void
paintDynamic(Canvas canvas, Size size, ChartContext context) → void
paintStatic(Canvas canvas, Size size, ChartContext context) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited