HitTestEngine class

Canvas-based hit testing — never uses widget trees.

Constructors

HitTestEngine()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
test(Offset position, ChartContext context, List<ChartRenderer> renderers, {double tolerance = 12}) ChartHitResult?
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited