ChartHitResult class

Result of a canvas hit test against chart geometry.

Constructors

ChartHitResult({required HitRegion region, double distance = 0})
const

Properties

dataPercent double?
no setter
dataX double?
no setter
dataY double?
no setter
distance double
final
hashCode int
The hash code for this object.
no setterinherited
label String?
no setter
pointIndex int
no setter
region HitRegion
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seriesId String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited