AxisLayer class

Renders X and Y axes with labels.

Inheritance

Constructors

AxisLayer({int tickCount = 5})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isStatic bool
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tickCount int
final
zIndex int
Layer z-order — lower renders first.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size, ChartContext context) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited