ChartLayer class abstract

A single render layer in the chart pipeline.

Implementers

Constructors

ChartLayer()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isStatic bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zIndex int
Layer z-order — lower renders first.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size, ChartContext context) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited