ChromeLayer class

Renders title and legend chrome above series data.

Inheritance

Constructors

ChromeLayer()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isStatic bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zIndex int
Layer z-order — lower renders first.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size, ChartContext context) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited