LayerStack class
Ordered stack of render layers.
Constructors
-
LayerStack({List<
ChartLayer> ? layers})
Properties
-
dynamicLayers
→ List<
ChartLayer> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
layers
→ List<
ChartLayer> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
staticLayers
→ List<
ChartLayer> -
no setter
Methods
-
add(
ChartLayer layer) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(
Canvas canvas, Size size, ChartContext context) → void -
remove(
ChartLayer layer) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited