ZoomPanController class
Manages zoom and pan state for chart viewports.
Constructors
- ZoomPanController({ChartViewport? initialViewport})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale → double
-
no setter
- viewport → ChartViewport
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pan(
double dx, double dy) → void -
reset(
ChartViewport viewport) → void -
setViewport(
ChartViewport viewport) → void -
toString(
) → String -
A string representation of this object.
inherited
-
zoom(
double factor, {double centerX = 0.5, double centerY = 0.5}) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited