PaintCache class

Caches Paint objects to avoid allocations in paint loops.

Constructors

PaintCache()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
fill(String key, Color color, {double? opacity}) Paint
get({required String key, required Color color, double strokeWidth = 1.0, PaintingStyle style = PaintingStyle.stroke, StrokeCap strokeCap = StrokeCap.round, StrokeJoin strokeJoin = StrokeJoin.round, bool isAntiAlias = true, double? opacity}) Paint
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited