BubbleDataPoint constructor

const BubbleDataPoint({
  1. required double x,
  2. required double y,
  3. required double size,
  4. String? label,
  5. bool showValue = true,
})

Creates a bubble data point.

x, y, and size are required and must be finite numbers. label is optional. showValue defaults to true to display the value on the chart.

Throws an AssertionError if size is not positive or not finite.

Implementation

const BubbleDataPoint({
  required super.x,
  required super.y,
  required this.size,
  super.label,
  super.showValue,
});