dataPoints property
The list of bubble data points in this data set.
Each point represents one bubble on the chart. Labels are stored in each BubbleDataPoint.label.
Implementation
final List<BubbleDataPoint> dataPoints;
The list of bubble data points in this data set.
Each point represents one bubble on the chart. Labels are stored in each BubbleDataPoint.label.
final List<BubbleDataPoint> dataPoints;