label property
Optional label for the data point (e.g., "Jan", "Q1").
Used for axis labels, tooltips, and legends. If null, the chart will use the x or y value as a fallback.
Implementation
final String? label;
Optional label for the data point (e.g., "Jan", "Q1").
Used for axis labels, tooltips, and legends. If null, the chart will use the x or y value as a fallback.
final String? label;