x property
The x-coordinate (horizontal position) of the data point.
This value represents the horizontal position on the chart. It should be a finite number (not NaN or Infinity).
Implementation
final double x;
The x-coordinate (horizontal position) of the data point.
This value represents the horizontal position on the chart. It should be a finite number (not NaN or Infinity).
final double x;