y property
The y-coordinate (vertical value) of the data point.
This value represents the vertical value on the chart. It should be a finite number (not NaN or Infinity).
Implementation
final double y;
The y-coordinate (vertical value) of the data point.
This value represents the vertical value on the chart. It should be a finite number (not NaN or Infinity).
final double y;