hoverRadius constant

double const hoverRadius

Hover radius for detecting point hovers (larger than tap for better UX).

The maximum distance from a hover position to a data point to trigger hover effects. Should be larger than tapRadius to provide better visual feedback before the user taps.

Default: 30.0 pixels

Implementation

static const double hoverRadius = 30.0;