datasetIndex property

int? datasetIndex
final

The index of the dataset containing the interacted element.

Non-null when isHit is true and the chart has multiple datasets. Always 0 for single-dataset charts.

Implementation

final int? datasetIndex;