isHit property
Whether an interaction was successfully detected.
True if a chart element was found at the interaction position, false otherwise. When false, all other fields will be null.
Implementation
final bool isHit;
Whether an interaction was successfully detected.
True if a chart element was found at the interaction position, false otherwise. When false, all other fields will be null.
final bool isHit;