ChartPoint class

A single data point in chart data space.

Annotations

Constructors

ChartPoint({required double x, required double y, String? label, Map<String, Object?> metadata = const {}})
const

Properties

hashCode int
The hash code for this object.
no setteroverride
label String?
final
metadata Map<String, Object?>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x double
final
y double
final

Methods

copyWith({double? x, double? y, String? label, Map<String, Object?>? metadata}) ChartPoint
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override