RadarDataPoint constructor

const RadarDataPoint({
  1. required String label,
  2. required double value,
  3. bool showValue = true,
})

Creates a radar data point.

label must not be empty. value must be non-negative and finite. showValue defaults to true to display the value on the chart.

Throws an AssertionError if value is negative or not finite, or if label is empty.

Implementation

const RadarDataPoint({
  required this.label,
  required this.value,
  this.showValue = true,
});