showValue property
Whether to show the value for this data point.
When true (default), the value will be displayed on the chart. When false, the value will be hidden.
Implementation
final bool showValue;
Whether to show the value for this data point.
When true (default), the value will be displayed on the chart. When false, the value will be hidden.
final bool showValue;