value property
The value on this axis (0.0 to maxValue).
Must be non-negative and finite. The value determines how far from the center the point is plotted on this axis.
Implementation
final double value;
The value on this axis (0.0 to maxValue).
Must be non-negative and finite. The value determines how far from the center the point is plotted on this axis.
final double value;