RadarDataSet class

Represents a collection of radar/spider chart data points.

Contains multiple axes with values forming a polygon shape. Each data point represents one axis on the radar chart.

Example

RadarDataSet(
  color: Colors.blue,
  dataPoints: [
    RadarDataPoint(label: 'Speed', value: 80),
    RadarDataPoint(label: 'Quality', value: 90),
    RadarDataPoint(label: 'Design', value: 75),
  ],
)

See also:

Constructors

RadarDataSet({required Color color, required List<RadarDataPoint> dataPoints})
Creates a radar data set.

Properties

color Color
The color used to render the polygon and points in this data set.
final
dataPoints List<RadarDataPoint>
The list of radar data points in this data set.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Color? color, List<RadarDataPoint>? dataPoints}) RadarDataSet
Creates a copy of this radar data set with the given fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override