dataPoints property

List<RadarDataPoint> dataPoints
final

The list of radar data points in this data set.

Each point represents one axis on the radar chart. All data sets in a radar chart should have the same number of points with matching axis labels. Each RadarDataPoint has its own label for the axis name.

Implementation

final List<RadarDataPoint> dataPoints;