ChartViewport class

Defines the visible data-space region for a chart.

Annotations

Constructors

ChartViewport({required double minX, required double maxX, required double minY, required double maxY})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
height double
no setter
maxX double
final
maxY double
final
minX double
final
minY double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double
no setter

Methods

copyWith({double? minX, double? maxX, double? minY, double? maxY}) ChartViewport
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pan(double dx, double dy) ChartViewport
toString() String
A string representation of this object.
inherited
zoom(double factor, {double centerX = 0.5, double centerY = 0.5}) ChartViewport

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromPoints(Iterable<double> xs, Iterable<double> ys, {double padding = 0.05}) ChartViewport