showAxis property
Whether to show axis lines.
Defaults to true. Axis lines mark the boundaries of the chart area.
Implementation
final bool showAxis;
Whether to show axis lines.
Defaults to true. Axis lines mark the boundaries of the chart area.
final bool showAxis;