showGrid property
Whether to show grid lines.
Defaults to true. Grid lines help users read values from the chart.
Implementation
final bool showGrid;
Whether to show grid lines.
Defaults to true. Grid lines help users read values from the chart.
final bool showGrid;