theme property
The theme to use for styling the chart.
Controls colors, fonts, and visual appearance of grid, axes, and labels.
Implementation
final ChartTheme theme;
The theme to use for styling the chart.
Controls colors, fonts, and visual appearance of grid, axes, and labels.
final ChartTheme theme;