SplineChartPainter class
Custom painter for spline charts with smooth bezier curves
- Inheritance
-
- Object
- Listenable
- CustomPainter
- BaseChartPainter
- SplineChartPainter
Constructors
-
SplineChartPainter({required ChartTheme theme, required List<
ChartDataSet> dataSets, bool showGrid = true, bool showAxis = true, bool showLabel = true, double lineWidth = 3.0, bool showArea = true, bool showPoints = true, double animationProgress = 1.0, ChartInteractionResult? selectedPoint, ChartInteractionResult? hoveredPoint}) -
const
Properties
- animationProgress → double
-
final
-
dataSets
→ List<
ChartDataSet> -
The data sets to render in the chart.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hoveredPoint → ChartInteractionResult?
-
final
- lineWidth → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedPoint → ChartInteractionResult?
-
final
- semanticsBuilder → SemanticsBuilderCallback?
-
Returns a function that builds semantic information for the picture drawn
by this painter.
no setterinherited
- showArea → bool
-
final
- showAxis → bool
-
Whether to show axis lines.
finalinherited
- showGrid → bool
-
Whether to show grid lines.
finalinherited
- showLabel → bool
-
Whether to show axis labels.
finalinherited
- showPoints → bool
-
final
- theme → ChartTheme
-
The theme to use for styling the chart.
finalinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be notified when it is time to repaint.
inherited
-
drawAxes(
Canvas canvas, Size size, double minX, double maxX, double minY, double maxY) → void -
Draw axis lines.
inherited
-
drawAxisLabels(
Canvas canvas, Size size, double minX, double maxX, double minY, double maxY, {List< ChartDataSet> ? dataSets}) → void -
Draw axis labels (optimized with text style caching).
inherited
-
drawGrid(
Canvas canvas, Size size, double minX, double maxX, double minY, double maxY) → void -
Draw grid lines (optimized with batched operations).
inherited
-
getDataBounds(
double getValue(ChartDataPoint), double combine(double, double)) → void -
Get data bounds (to be overridden by subclasses).
inherited
-
getNiceMaxY(
double maxY, {int targetIntervals = 5}) → double -
Helper to calculate a "nice" maximum Y value for axis scaling.
inherited
-
hitTest(
Offset position) → bool? -
Called whenever a hit test is being performed on an object that is using
this custom paint delegate.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(
Canvas canvas, Size size) → void -
Called whenever the object needs to paint. The given Canvas has its
coordinate space configured such that the origin is at the top left of the
box. The area of the box is the size of the
sizeargument.override -
pointToCanvas(
ChartDataPoint point, Size size, double minX, double maxX, double minY, double maxY) → Offset -
Convert data point to canvas coordinates (optimized).
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that the
object notifies when it is time to repaint.
inherited
-
shouldRebuildSemantics(
covariant CustomPainter oldDelegate) → bool -
Called whenever a new instance of the custom painter delegate class is
provided to the RenderCustomPaint object, or any time that a new
CustomPaint object is created with a new instance of the custom painter
delegate class (which amounts to the same thing, because the latter is
implemented in terms of the former).
inherited
-
shouldRepaint(
covariant SplineChartPainter oldDelegate) → bool -
Called whenever a new instance of the custom painter delegate class is
provided to the RenderCustomPaint object, or any time that a new
CustomPaint object is created with a new instance of the custom painter
delegate class (which amounts to the same thing, because the latter is
implemented in terms of the former).
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited