LabelRotation class

Common label rotation angles in degrees for convenience.

Use these constants when setting label rotation:

ChartTheme.light().copyWith(
  xAxisLabelRotation: LabelRotation.diagonalDown, // 45 degrees
)

// Or use custom degrees:
ChartDataPoint(
  x: 1,
  y: 20,
  label: 'January',
  xAxisLabelRotation: 30, // 30 degrees
)

Constructors

LabelRotation()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

diagonalDown → const int
45 degrees clockwise (slanted down to the right)
diagonalUp → const int
45 degrees counter-clockwise (slanted up to the right)
none → const int
No rotation (horizontal labels)
slightDown → const int
30 degrees clockwise
slightUp → const int
30 degrees counter-clockwise
steepDown → const int
60 degrees clockwise
steepUp → const int
60 degrees counter-clockwise
vertical → const int
90 degrees clockwise (vertical, reading top to bottom)
verticalUp → const int
90 degrees counter-clockwise (vertical, reading bottom to top)