emptyWidget property
Custom widget shown when the chart has no data or all values are zero. If null, charts use ChartEmptyState with emptyMessage.
Implementation
final Widget? emptyWidget;
Custom widget shown when the chart has no data or all values are zero. If null, charts use ChartEmptyState with emptyMessage.
final Widget? emptyWidget;