errorWidget property
Custom widget shown when the chart is in error state. If null, charts use the default error UI with errorMessage.
Implementation
final Widget? errorWidget;
Custom widget shown when the chart is in error state. If null, charts use the default error UI with errorMessage.
final Widget? errorWidget;