header property
Optional widget displayed below the subtitle and above the chart.
If null, no header is shown.
Implementation
final Widget? header;
Optional widget displayed below the subtitle and above the chart.
If null, no header is shown.
final Widget? header;