direction property
Whether items are laid out in a row (horizontal) or column (vertical). The horizontal variant wraps onto multiple lines when space runs out.
Implementation
final Axis direction;
Whether items are laid out in a row (horizontal) or column (vertical). The horizontal variant wraps onto multiple lines when space runs out.
final Axis direction;