constrained property
When true (default), the child stays within the viewport. When false, the child can be panned outside the viewport bounds.
Implementation
final bool constrained;
When true (default), the child stays within the viewport. When false, the child can be panned outside the viewport bounds.
final bool constrained;