onInteractionEnd property
Invoked when the user finishes a pan or pinch gesture.
Implementation
final ValueChanged<ScaleEndDetails>? onInteractionEnd;
Invoked when the user finishes a pan or pinch gesture.
final ValueChanged<ScaleEndDetails>? onInteractionEnd;