onInteractionStart property
Invoked when the user begins a pan or pinch gesture.
Implementation
final ValueChanged<ScaleStartDetails>? onInteractionStart;
Invoked when the user begins a pan or pinch gesture.
final ValueChanged<ScaleStartDetails>? onInteractionStart;