PieChartWidget class

Modern pie chart with gradient sections and animations

Inheritance

Constructors

PieChartWidget({Key? key, required List<PieData> data, double borderWidth = 2.0, bool showLegend = true, bool showLabel = true, Axis legendLayout = Axis.horizontal, String? title, String? subtitle, Widget? header, Widget? footer, PieSegmentCallback? onSegmentTap, bool isLoading = false, bool isError = false, double? height, EdgeInsets? padding, EdgeInsets? margin, ChartsConfig? config})
const

Properties

borderWidth double
final
config ChartsConfig?
final
data List<PieData>
final
final
hashCode int
The hash code for this object.
no setterinherited
final
height double?
final
isError bool
final
isLoading bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
legendLayout Axis
Layout of chart and legend: Axis.horizontal = Row (chart left, legend right), .vertical = Column (chart top, legend below).
final
margin EdgeInsets?
final
onSegmentTap PieSegmentCallback?
final
padding EdgeInsets?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showLabel bool
final
showLegend bool
final
subtitle String?
final
title String?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<PieChartWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited