AreaChartRenderer class
Area chart — line chart with fill enabled.
- Inheritance
-
- Object
- ChartRenderer
- LineChartRenderer
- AreaChartRenderer
Constructors
- AreaChartRenderer({LineChartMode mode = LineChartMode.smooth})
-
const
Properties
- fillArea → bool
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- mode → LineChartMode
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
draw(
Canvas canvas, Size size, ChartContext context) → void -
inherited
-
hitRegions(
ChartContext context) → List< HitRegion> -
Optional hit regions for interaction.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited