FunnelChartRenderer class
Canvas-based funnel chart — stage width proportional to value.
- Inheritance
-
- Object
- ChartRenderer
- FunnelChartRenderer
Constructors
- FunnelChartRenderer({double gap = 4, bool labelStages = true, bool sortDescending = true})
-
const
Properties
- gap → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- labelStages → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sortDescending → bool
-
final
Methods
-
draw(
Canvas canvas, Size size, ChartContext context) → void -
override
-
hitRegions(
ChartContext context) → List< HitRegion> -
Optional hit regions for interaction.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited