LineChartRenderer class
Canvas-based line chart renderer.
- Inheritance
-
- Object
- ChartRenderer
- LineChartRenderer
- Implementers
Constructors
- LineChartRenderer({LineChartMode mode = LineChartMode.smooth, bool fillArea = false})
-
const
Properties
- fillArea → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mode → LineChartMode
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
draw(
Canvas canvas, Size size, ChartContext context) → void -
override
-
hitRegions(
ChartContext context) → List< HitRegion> -
Optional hit regions for interaction.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited