WaterfallChartRenderer class
Canvas-based waterfall chart renderer.
- Inheritance
-
- Object
- ChartRenderer
- WaterfallChartRenderer
Constructors
- WaterfallChartRenderer({WaterfallValueMode valueMode = WaterfallValueMode.delta, double barWidthFactor = 0.55, bool connectorLines = true})
-
const
Properties
- barWidthFactor → double
-
final
- connectorLines → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- valueMode → WaterfallValueMode
-
final
Methods
-
draw(
Canvas canvas, Size size, ChartContext context) → void -
override
-
hitRegions(
ChartContext context) → List< HitRegion> -
Optional hit regions for interaction.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
waterfallViewport(
List< ChartPoint> points, {WaterfallValueMode mode = WaterfallValueMode.delta, double padding = 0.08}) → ChartViewport - Viewport spanning all bar tops and bottoms.