ChartChrome class

Shared chart chrome: title, legend, and card border.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

drawBorder(Canvas canvas, Size size, ChartContext context) → void
drawLegend(Canvas canvas, Size size, ChartContext context) → void
drawSubtitle(Canvas canvas, Size size, ChartContext context) → void
drawTitle(Canvas canvas, Size size, ChartContext context) → void
headerReservedHeight(ChartConfig config) double
Top margin for title + subtitle block.
legendReservedHeight(ChartConfig config) double
legendReservedLeft(ChartConfig config) double
legendReservedRight(ChartConfig config) double