ChartEngine class
Central chart engine — builds context and drives the render pipeline.
Constructors
-
ChartEngine({required ChartConfig config, required List<
ChartRenderer> renderers, ChartTheme? theme, ZoomPanController? zoomPan, List<ChartLayer> ? extraLayers})
Properties
- config → ChartConfig
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- layerStack → LayerStack
-
no setter
- pipeline → RenderPipeline
-
no setter
-
renderers
→ List<
ChartRenderer> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- theme → ChartTheme
-
final
- zoomPan → ZoomPanController
-
final
Methods
-
buildContext(
Size size, {double animationValue = 1.0, ChartHitResult? hoveredHit, ChartHitResult? selectedHit, Offset? crosshairPosition}) → ChartContext -
markSeriesDirty(
ChartContext context) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(
Canvas canvas, Size size, ChartContext context) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited