GestureEngine class
Handles pointer interactions: hover, tap, drag, zoom, pan.
Constructors
- GestureEngine({HitTestEngine hitTestEngine = const HitTestEngine(), void onHover(ChartHitResult? hit, Offset position)?, void onTap(ChartHitResult? hit, Offset position)?, void onSelection(ChartHitResult hit)?, void onZoom(double scale, Offset focal)?, void onPan(double dx, double dy)?, bool enableCrosshair = true, bool enableZoomPan = true})
Properties
- enableCrosshair → bool
-
final
- enableZoomPan → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hitTestEngine → HitTestEngine
-
final
- onHover → void Function(ChartHitResult? hit, Offset position)?
-
final
- onPan → void Function(double dx, double dy)?
-
final
- onSelection → void Function(ChartHitResult hit)?
-
final
- onTap → void Function(ChartHitResult? hit, Offset position)?
-
final
- onZoom → void Function(double scale, Offset focal)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
crosshairForHover(
Offset position, ChartContext context) → Offset? -
handleHover(
Offset position, ChartEngine engine, ChartContext context) → ChartHitResult? -
handlePanUpdate(
DragUpdateDetails details, ZoomPanController zoomPan, ChartContext context) → void -
handleScaleStart(
) → void -
handleScaleUpdate(
ScaleUpdateDetails details, ZoomPanController zoomPan, ChartContext context) → void -
handleTap(
Offset position, ChartEngine engine, ChartContext context) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited