ChartTemplate class
Applies the shared dashboard design system to ChartConfig instances.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
dashboardTheme(
) → ChartTheme -
resolve(
ChartConfig config, {ChartTheme? theme}) → ChartConfig - Resolves theme + chrome defaults for the active template.