BubbleDataPoint constructor

BubbleDataPoint({
  1. required dynamic x,
  2. required dynamic y,
  3. required dynamic size,
  4. String? label,
  5. bool showValue = true,
})

Creates a bubble data point.

x, y, and size are required and must be finite numbers or numeric strings. label is optional. showValue defaults to true to display the value on the chart.

Throws an AssertionError if size is not positive or not finite.

Implementation

BubbleDataPoint({required super.x, required super.y, required dynamic size, super.label, super.showValue})
  : size = _parseSize(size);