size property
The size of the bubble (third dimension).
This value is used to determine the radius of the bubble. Must be positive and finite. The actual rendered size will be scaled based on the min/max size range of the chart.
Implementation
final double size;