ChartConfig class
Global configuration for a chart instance.
- Annotations
Constructors
-
ChartConfig({List<
ChartSeries> series = const [], ChartViewport? viewport, ChartTheme? theme, ChartTemplateStyle template = ChartTemplateStyle.dashboard, ChartStyle style = ChartStyle.gradient, bool showGrid = true, bool showAxis = true, String? xAxisTitle, String? yAxisTitle, String? title, String? subtitle, bool showLegend = false, LegendPosition legendPosition = LegendPosition.bottom, bool showBorder = false, double barBorderRadius = 4, bool animate = true, Duration animationDuration = const Duration(milliseconds: 300), double curveTension = 0.35, String? semanticLabel}) -
const
Properties
- animate → bool
-
final
- animationDuration → Duration
-
final
- barBorderRadius → double
-
final
- curveTension → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- legendPosition → LegendPosition
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String?
-
final
-
series
→ List<
ChartSeries> -
final
- showAxis → bool
-
final
- showBorder → bool
-
final
- showGrid → bool
-
final
- showLegend → bool
-
final
- style → ChartStyle
-
final
- subtitle → String?
-
final
- template → ChartTemplateStyle
-
final
- theme → ChartTheme?
-
final
- title → String?
-
final
- viewport → ChartViewport?
-
final
- xAxisTitle → String?
-
final
- yAxisTitle → String?
-
final
Methods
-
copyWith(
{List< ChartSeries> ? series, ChartViewport? viewport, ChartTheme? theme, ChartTemplateStyle? template, ChartStyle? style, bool? showGrid, bool? showAxis, String? xAxisTitle, String? yAxisTitle, String? title, String? subtitle, bool? showLegend, LegendPosition? legendPosition, bool? showBorder, double? barBorderRadius, bool? animate, Duration? animationDuration, double? curveTension, String? semanticLabel}) → ChartConfig -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited