ChartSeries class
A named collection of ChartPoints with optional styling.
- Annotations
Constructors
-
ChartSeries({required String id, required String name, required List<
ChartPoint> points, SeriesStyle style = const SeriesStyle()}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- name → String
-
final
-
points
→ List<
ChartPoint> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → SeriesStyle
-
final
Methods
-
copyWith(
{String? id, String? name, List< ChartPoint> ? points, SeriesStyle? style}) → ChartSeries -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited