SeriesStyle class
Style configuration for a data series.
- Annotations
Constructors
Properties
- color → Color?
-
final
- fillColor → Color?
-
final
- gradient → Gradient?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- markerRadius → double
-
final
- opacity → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showMarkers → bool
-
final
- strokeWidth → double
-
final
Methods
-
copyWith(
{Color? color, double? strokeWidth, Color? fillColor, Gradient? gradient, bool? showMarkers, double? markerRadius, double? opacity}) → SeriesStyle -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited