RadarDataPoint constructor

RadarDataPoint({
  1. required String label,
  2. required dynamic value,
  3. bool showValue = true,
})

Creates a radar data point.

label must not be empty. value must be a non-negative finite number or numeric string. showValue defaults to true to display the value on the chart.

Throws an AssertionError if value is negative or not finite, or if label is empty.

Implementation

RadarDataPoint({
  required this.label,
  required dynamic value,
  this.showValue = true,
}) : value = _parseValue(value);