copyWith method
Creates a copy of this radar data set with the given fields replaced.
Returns a new RadarDataSet with the same values as this one, except for the fields that are explicitly provided.
Implementation
RadarDataSet copyWith({Color? color, List<RadarDataPoint>? dataPoints}) {
return RadarDataSet(
color: color ?? this.color,
dataPoints: dataPoints ?? this.dataPoints,
);
}