ChartFormatUtils class
Utility functions for formatting chart values.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
formatValue(
double value, {int fractionDigits = 2}) → String -
Formats a double value to a string.
If the value is effectively an integer (e.g. 10.0), it returns "10".
Otherwise, it returns the value as a string with up to
fractionDigitsdecimal places. Trailing zeros are removed.