ChartLegendItem class
One entry in a ChartLegend.
Constructors
- ChartLegendItem({required Color color, required String label, String? value})
-
const
Properties
- color → Color
-
The swatch color shown beside the label.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- label → String
-
The display label for this series.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String?
-
Optional value or summary (for example, "12.5M" or "42%") shown on the
right side of the row.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override